@@ -1,6 +1,6 @@
 #!/bin/bash
 
-ALL_LANGUAGES="ru_RU fi_FI es_ES es_MX pl_PL it_IT"
+ALL_LANGUAGES="ru_RU fi_FI es_ES es_MX pl_PL it_IT nl_NL"
 
 xgettext --from-code=UTF-8 --keyword=_ --keyword=Q_ -f po/POTFILES.in -s -C -o po/livewp.pot
 cd po
