@@ -913,9 +913,10 @@ change_tape(Actor *actor, AWallpaperPlugin *desktop_plugin)
 void
 change_slideshow(Actor *actor, AWallpaperPlugin *desktop_plugin)
 {
-	gint num, next, prev, now;
+	gint num, next, prev, now, w, h;
 	Actor *a1 = NULL, *a2 = NULL;
-    
+    GtkImage *image;
+    GdkPixbuf *pixbuf;
     struct timeval tvb;
     suseconds_t ms;
     long sec;
@@ -935,6 +936,15 @@ change_slideshow(Actor *actor, AWallpaperPlugin *desktop_plugin)
 	    a2->visible = TRUE;
 	    create_hildon_actor(a2, desktop_plugin);
         set_actor_opacity(a2, 0);
+        pixbuf = gtk_image_get_pixbuf(a2->image);
+        w = gdk_pixbuf_get_width(pixbuf);
+        h = gdk_pixbuf_get_height(pixbuf);
+        if (w < 800) {
+            set_actor_position(a2, (800-w)/2, 0, 5, desktop_plugin);
+        }
+        if (h < 480){
+            set_actor_position(a2, 0, (480-h)/2, 5, desktop_plugin);
+        }
         actor->z = next;
     }else {
         a2 = g_ptr_array_index(actor->child, next);
