@@ -6,8 +6,8 @@
  *       for the code
  * 
  * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 2.1 of
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  * 
  * This software is distributed in the hope that it will be useful, but
@@ -65,8 +65,6 @@ GType animation_wallpaper_plugin_get_type(void);
 Animation_WallpaperPrivate* animation_wallpaper_plugin_new (void);
 G_END_DECLS
 void lw_settings(gpointer user_data, gpointer data);
-gint read_config(Animation_WallpaperPrivate *priv);
-void save_config(Animation_WallpaperPrivate *priv);
 //void run_long_timeout(AWallpaperPlugin *desktop_plugin);
 void get_sun_screen_pos(double alt, double azm, gint * x, gint * y);
 void show_settings(GtkWidget *widget, Animation_WallpaperPrivate *priv);
@@ -76,5 +74,5 @@ gint current_active_view(void);
 //gboolean long_timeout (AWallpaperPlugin *desktop_plugin);
 void desktop_plugin_visible_notify (GObject *object, GParamSpec *spec, AWallpaperPlugin *desktop_plugin);
 void send_dbus_signal (Animation_WallpaperPrivate *priv, const gchar *interface, const gchar *path, const gchar *member);
-
+gboolean get_one_in_all_views_from_config(void);
 #endif
